// Copyright 2024 Florian Beisel
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package models

import "time"

// Hostname Model
// @Description Model of the Hostname as it
// @Description is represented in the database
type Hostname struct {
	ID         int                    `json:"Id" example:"25"`                           // Internal ID of the Hostname within the database
	Category   string                 `json:"Category" example:"notebook"`               // Category / Rule that was used when generating the hostname
	Hostname   string                 `json:"Hostname" example:"ISEHENNB0009"`           // Generated hostname
	Parameters map[string]interface{} `json:"Parameters"`                                // Parameter object of rule specific attributes, see rule.* models
	CreatedAt  time.Time              `json:"Created_at" example:"2024-01-16T12:53:59Z"` // Creation Time of the entry
}

// SimpleHostnameResponse
// @Description Model of the Hostname as returned by
// @Description POST endpoint
type SimpleHostnameResponse struct {
	Hostname string `json:"Hostname"` // Name of the newly generated host
}
